/// <reference types="node" />
import { WebhookEvent, Webhooks } from "@octokit/webhooks";
import Logger from "bunyan";
import express from "express";
import Redis from "ioredis";
import { Server } from "http";
import { Application } from "./application";
import { Context } from "./context";
import { ProbotOctokit, ProbotOctokitCore } from "./github/octokit";
export declare class Probot {
    static run(appFn: ApplicationFunction | string[]): Promise<Probot>;
    server: express.Application;
    webhook: Webhooks;
    logger: Logger;
    options: Options;
    throttleOptions: any;
    private httpServer?;
    private apps;
    private githubToken?;
    private Octokit;
    private octokit;
    private cache;
    constructor(options: Options);
    receive(event: WebhookEvent): Promise<[void, void, void][]>;
    load(appFn: string | ApplicationFunction): Application;
    setup(appFns: Array<string | ApplicationFunction>): void;
    start(): Server;
    stop(): void;
}
export declare const createProbot: (options: Options) => Probot;
export declare type ApplicationFunction = (app: Application) => void;
export interface Options {
    webhookPath?: string;
    secret?: string;
    id?: number;
    cert?: string;
    githubToken?: string;
    webhookProxy?: string;
    port?: number;
    redisConfig?: Redis.RedisOptions;
    Octokit?: typeof ProbotOctokit;
}
export { Logger, Context, Application, ProbotOctokit, ProbotOctokitCore };
